@@ -11,12 +11,14 @@ impl<T> IntoPyResult<T> for Result<T, h3ron::Error> {
             Ok(v) => Ok(v),
             Err(err) => match err {
                 h3ron::Error::InvalidInput
-                | h3ron::Error::MixedResolutions
-                | h3ron::Error::InvalidH3Resolution
-                | h3ron::Error::InvalidH3Index => Err(PyValueError::new_err(err.to_string())),
+                | h3ron::Error::MixedResolutions(..)
+                | h3ron::Error::InvalidH3Resolution(_)
+                | h3ron::Error::InvalidH3Direction(_)
+                | h3ron::Error::InvalidH3Cell(_)
+                | h3ron::Error::InvalidH3Edge(_) => Err(PyValueError::new_err(err.to_string())),
 
                 h3ron::Error::PentagonalDistortion
-                | h3ron::Error::NoLocalIJCoordinates
+                | h3ron::Error::NoLocalIjCoordinates
                 | h3ron::Error::LineNotComputable
                 | h3ron::Error::UnsupportedOperation => {
                     Err(PyRuntimeError::new_err(err.to_string()))
