@@ -2,7 +2,8 @@ use std::hash::Hash;
 use std::str::FromStr;
 
 use ndarray::ArrayView2;
-use numpy::{Element, IntoPyArray, Ix1, PyArray, PyReadonlyArray2};
+use numpy::{IntoPyArray, Ix1, PyArray, PyReadonlyArray2};
+use ordered_float::OrderedFloat;
 use pyo3::exceptions::PyValueError;
 use pyo3::{prelude::*, wrap_pyfunction, PyNativeType};
 
@@ -76,16 +77,15 @@ pub fn nearest_h3_resolution(
 
 #[allow(clippy::type_complexity)]
 fn raster_to_h3<'a, T>(
-    py: Python,
     arr: &'a ArrayView2<'a, T>,
     transform: &'a Transform,
     nodata_value: &'a Option<T>,
     h3_resolution: u8,
     axis_order_str: &str,
     compacted: bool,
-) -> PyResult<(Py<PyArray<T, Ix1>>, Py<PyArray<u64, Ix1>>)>
+) -> PyResult<(Vec<T>, Vec<u64>)>
 where
-    T: PartialEq + Sized + Sync + Eq + Hash + Element,
+    T: PartialEq + Sized + Sync + Eq + Hash + Copy,
 {
     let axis_order = AxisOrder::from_str(axis_order_str)?;
     check_valid_h3_resolution(h3_resolution).into_pyresult()?;
@@ -106,15 +106,12 @@ where
                 .iter_uncompacted_indexes(h3_resolution)
                 .collect()
         };
-        let mut this_values = vec![value.clone(); this_indexes.len()];
+        let mut this_values = vec![*value; this_indexes.len()];
         values.append(&mut this_values);
         h3indexes.append(&mut this_indexes);
     }
 
-    Ok((
-        values.into_pyarray(py).to_owned(),
-        h3indexes.into_pyarray(py).to_owned(),
-    ))
+    Ok((values, h3indexes))
 }
 
 macro_rules! make_raster_to_h3_variant {
@@ -131,7 +128,6 @@ macro_rules! make_raster_to_h3_variant {
         ) -> PyResult<(Py<PyArray<$dtype, Ix1>>, Py<PyArray<u64, Ix1>>)> {
             let arr = np_array.as_array();
             raster_to_h3(
-                py,
                 &arr,
                 transform,
                 &nodata_value,
@@ -139,9 +135,53 @@ macro_rules! make_raster_to_h3_variant {
                 axis_order_str,
                 compacted,
             )
+            .map(|(values, h3indexes)| {
+                (
+                    values.into_pyarray(py).to_owned(),
+                    h3indexes.into_pyarray(py).to_owned(),
+                )
+            })
         }
     };
 }
+
+macro_rules! make_raster_to_h3_float_variant {
+    ($name:ident, $dtype:ty) => {
+        #[pyfunction]
+        fn $name<'py>(
+            py: Python<'py>,
+            np_array: PyReadonlyArray2<$dtype>,
+            transform: &Transform,
+            nodata_value: Option<$dtype>,
+            h3_resolution: u8,
+            axis_order_str: &str,
+            compacted: bool,
+        ) -> PyResult<(Py<PyArray<$dtype, Ix1>>, Py<PyArray<u64, Ix1>>)> {
+            {
+                let arr = np_array.as_array();
+                // create a copy with the values wrapped in ordered floats to
+                // support the internal hashing
+                let of_arr = arr.map(|v| OrderedFloat::from(*v));
+                raster_to_h3(
+                    &of_arr.view(),
+                    transform,
+                    &nodata_value.map(OrderedFloat::from),
+                    h3_resolution,
+                    axis_order_str,
+                    compacted,
+                )
+            }
+            .map(|(mut values, h3indexes)| {
+                let float_vec: Vec<_> = values.drain(..).map(|v| *v).collect();
+                (
+                    float_vec.into_pyarray(py).to_owned(),
+                    h3indexes.into_pyarray(py).to_owned(),
+                )
+            })
+        }
+    };
+}
+
 // generate some specialized variants of raster_to_h3 to expose to python
 make_raster_to_h3_variant!(raster_to_h3_u8, u8);
 make_raster_to_h3_variant!(raster_to_h3_i8, i8);
@@ -151,8 +191,8 @@ make_raster_to_h3_variant!(raster_to_h3_u32, u32);
 make_raster_to_h3_variant!(raster_to_h3_i32, i32);
 make_raster_to_h3_variant!(raster_to_h3_u64, u64);
 make_raster_to_h3_variant!(raster_to_h3_i64, i64);
-//make_raster_to_h3_variant!(raster_to_h3_f32, f32);
-//make_raster_to_h3_variant!(raster_to_h3_f64, f64);
+make_raster_to_h3_float_variant!(raster_to_h3_f32, f32);
+make_raster_to_h3_float_variant!(raster_to_h3_f64, f64);
 
 pub fn init_raster_submodule(m: &PyModule) -> PyResult<()> {
     m.add("Transform", m.py().get_type::<Transform>())?;
@@ -166,8 +206,8 @@ pub fn init_raster_submodule(m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(raster_to_h3_i32, m)?)?;
     m.add_function(wrap_pyfunction!(raster_to_h3_u64, m)?)?;
     m.add_function(wrap_pyfunction!(raster_to_h3_i64, m)?)?;
-    //m.add_function(wrap_pyfunction!(raster_to_h3_f32, m)?)?;
-    //m.add_function(wrap_pyfunction!(raster_to_h3_f64, m)?)?;
+    m.add_function(wrap_pyfunction!(raster_to_h3_f32, m)?)?;
+    m.add_function(wrap_pyfunction!(raster_to_h3_f64, m)?)?;
 
     Ok(())
 }
